@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use 5.006;
 use strict;
 use warnings;
@@ -13,7 +13,7 @@ use Digest::SHA;
 
 our $JSON;
 BEGIN {
-	$JSON = JSON->new->utf8->allow_blessed->convert_blessed;
+	$JSON = JSON->new->utf8->canonical(1)->allow_blessed->convert_blessed;
 }
 
 sub new {
@@ -67,7 +67,7 @@ sub run {
 	}
 
 	$j->sid = $j->request->cookies->{sid};
-
+	
 	unless ($j->sid) {
 		my $h = Digest::SHA->new(256);
 		my @us = gettimeofday;
@@ -115,13 +115,13 @@ sub run {
 	}
 
 	my $cookie = {
-		value => $j->sid,
-		path  => $j->request->request_uri,
+		value => $logout ? "" : $j->sid,
+		path  => $j->request->uri,
 		secure => !$j->{_insecure_session},
-		expires => (ref $j->session && $j->session->expires) || time + 24 * 60 * 60,
+		expires => $logout ? time : ((ref $j->session && $j->session->expires) || time + 24 * 60 * 60),
 	};
 
-	return $j->okay_response($j->response, $logout ? {} : $cookie);
+	return $j->okay_response($j->response, $cookie);
 }
 
 sub okay_response {
@@ -299,8 +299,10 @@ Version 0.01
 
 	plackup MyAPI.psgi
 
-	GET http://localhost:5000/?req=hello_world # {"hello":"world","errors":[],"authenticated":1,"error":false,"status_code":200}
-	GET http://localhost:5000/?req=hello_world&not=1 # {"status_code":400,"error":true,"errors":["Invalid request"],"authenticated":0}
+	GET http://localhost:5000/?req=hello_world
+	# {"authenticated":1,"error":false,"errors":[],"hello":"world","status_code":200}
+	GET http://localhost:5000/?req=hello_world&not=1 
+	# {"authenticated":0,"error":true,"errors":["Invalid request"],"status_code":400}
 
 =cut
 
